@@ -33,9 +33,10 @@
 #  define KACTIVITIES_DEPRECATED_NO_EXPORT KACTIVITIES_NO_EXPORT KACTIVITIES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KACTIVITIES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KACTIVITIES_NO_DEPRECATED
+#    define KACTIVITIES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
